@@ -1,6 +1,8 @@
 local_load_all_quiet()
 
 test_that("translation domain correctly loaded", {
+  skip_if_c_locale()
+
   load_all(test_path("testTranslations"))
   withr::defer(unload("testTranslations"))
 
@@ -10,7 +12,9 @@ test_that("translation domain correctly loaded", {
   expect_equal(length(temp_po_dirs("testTranslations")), 1)
 })
 
-test_that("modifed translations are correctly reloaded", {
+test_that("modified translations are correctly reloaded", {
+  skip_if_c_locale()
+
   pkg <- withr::local_tempdir()
   file.copy(dir(test_path("testTranslations"), full.names = TRUE), pkg, recursive = TRUE)
 
